""" version which can be consumed from within the module """
VERSION_STR = "0.0.17"
DESCRIPTION = "command line utilities to help you work with paths"
APP_NAME = "pypathutil"
LOGGER_NAME = "pypathutil"
